@@ -1,43 +1,56 @@
-from __future__ import unicode_literals
-
 import collections
-import os
+import pathlib
+
+import pkg_resources
 
 from mopidy import config, ext
 
-__version__ = '2.0.3'
+__version__ = pkg_resources.get_distribution("Mopidy-InternetArchive").version
 
-SORT_FIELDS = ['%s %s' % (f, o) for o in ('asc', 'desc') for f in (
-    'addeddate',
-    'avg_rating',
-    'call_number',
-    'createdate',
-    'creatorSorter',
-    'date',
-    'downloads',
-    'foldoutcount',
-    'headerImage',
-    'identifier',
-    'imagecount',
-    'indexdate',
-    'languageSorter',
-    'licenseurl',
-    'month',
-    'nav_order',
-    'num_reviews',
-    'publicdate',
-    'reviewdate',
-    'stars',
-    'titleSorter',
-    'week',
-    'year'
-)]
+SORT_FIELDS = [
+    f"{f} {o}"
+    for o in ("asc", "desc")
+    for f in (
+        "addeddate",
+        "avg_rating",
+        "call_number",
+        "createdate",
+        "creatorSorter",
+        "date",
+        "downloads",
+        "foldoutcount",
+        "headerImage",
+        "identifier",
+        "imagecount",
+        "indexdate",
+        "languageSorter",
+        "licenseurl",
+        "month",
+        "nav_order",
+        "num_reviews",
+        "publicdate",
+        "reviewdate",
+        "stars",
+        "titleSorter",
+        "week",
+        "year",
+    )
+]
 
 
 class ConfigMap(config.ConfigValue):
 
-    def __init__(self, keys=config.String(), values=config.String(), delim='|',
-                 optional=False):
+    default_keys = config.String()
+
+    default_values = config.String()
+
+    def __init__(
+        self,
+        keys=default_keys,
+        values=default_values,
+        delim="|",
+        optional=False,
+    ):
         self.__keys = keys
         self.__values = values
         self.__delim = delim
@@ -54,25 +67,27 @@ class ConfigMap(config.ConfigValue):
 
     def serialize(self, value, display=False):
         if not value:
-            return b''
-        items = [
-            (self.__keys.serialize(k), self.__values.serialize(v))
-            for k, v in value.items()
-        ]
-        return config.List().serialize(map(self.__delim.join, items))
+            return ""
+        d = config.String().serialize(self.__delim)
+        return config.List().serialize(
+            [
+                self.__keys.serialize(k) + d + self.__values.serialize(v)
+                for k, v in value.items()
+            ]
+        )
 
 
 class Extension(ext.Extension):
 
-    dist_name = 'Mopidy-InternetArchive'
-    ext_name = 'internetarchive'
+    dist_name = "Mopidy-InternetArchive"
+    ext_name = "internetarchive"
     version = __version__
 
     def get_default_config(self):
-        return config.read(os.path.join(os.path.dirname(__file__), 'ext.conf'))
+        return config.read(pathlib.Path(__file__).parent / "ext.conf")
 
     def get_config_schema(self):
-        schema = super(Extension, self).get_config_schema()
+        schema = super().get_config_schema()
         schema.update(
             base_url=config.String(),
             collections=config.List(),
@@ -90,10 +105,11 @@ class Extension(ext.Extension):
             browse_order=config.Deprecated(),
             exclude_collections=config.Deprecated(),
             exclude_mediatypes=config.Deprecated(),
-            username=config.Deprecated()
+            username=config.Deprecated(),
         )
         return schema
 
     def setup(self, registry):
         from .backend import InternetArchiveBackend
-        registry.add('backend', InternetArchiveBackend)
+
+        registry.add("backend", InternetArchiveBackend)
